@@ -6,7 +6,6 @@ class Proto(asyncio.Protocol):
     """An asyncio Protocol class used to process incoming messages for a receiver.
     Implements TCP or UDP protocol."""
     def __init__(self, message: bytearray, type, port) -> None:
-        # core = core
         self.header = bytes(message)
         self.type = type
         self.transport = None
@@ -17,6 +16,7 @@ class Proto(asyncio.Protocol):
         if self.type == 'tcp':
             self.transport.write(self.header)
         else:
+            print(self.port)
             self.transport.sendto(self.header)
         log(f"[{self.type}] Receiver connected. Waiting for data.")
             
@@ -26,12 +26,12 @@ class Proto(asyncio.Protocol):
     #TCP
     def data_received(self, data: bytes) -> None:
         log("[tcp] data received")
-        receiver_callback(data)
+        asyncio.create_task(receiver_callback(data))
 
     #UDP
     def datagram_received(self, data, addr):
         log("[udp] data received")
-        receiver_callback(data)
+        asyncio.create_task(receiver_callback(data))
 
     #UDP
     def error_received(self, exc):
