@@ -23,8 +23,9 @@ receiver = {}  # holds receiver dicts with info and connection object
 loop = None
 receiver_task = None
 is_open = True
+shut_down = False
 
-def default_cb(data, *args, key='data'):
+async def default_cb(data, *args, key='data'):
     print("Callback not set for", key)
     if key == 'data':
         print("message:\n", data)
